@@ -135,6 +135,7 @@ GSS_CALLCONV gss_accept_sec_context(
             &local_minor_status,
             &context,
             actual_mech,
+            GSS_C_NO_NAME,
             acceptor_cred_handle,
             GSS_C_ACCEPT,
             nreq_flags);
@@ -537,7 +538,8 @@ GSS_CALLCONV gss_accept_sec_context(
                     &local_minor_status,
                     GSS_C_BOTH,
                     delegated_cred_handle_P,
-                    &delegated_cred);
+                    &delegated_cred,
+                    GLOBUS_FALSE);
                 if(GSS_ERROR(major_status))
                 {
                     globus_gsi_cred_handle_destroy(delegated_cred);
